@@ -1,5 +1,5 @@
 package Facebook::Graph;
-$Facebook::Graph::VERSION = '1.1101';
+
 use Moo;
 use MIME::Base64::URLSafe;
 use JSON;
@@ -11,7 +11,6 @@ use Facebook::Graph::Request;
 use Facebook::Graph::Publish::Post;
 use Facebook::Graph::Publish::Photo;
 use Facebook::Graph::Publish::Checkin;
-use Facebook::Graph::Publish::Like;
 use Facebook::Graph::Publish::Comment;
 use Facebook::Graph::Publish::Link;
 use Facebook::Graph::Publish::RSVPMaybe;
@@ -194,18 +193,6 @@ sub add_checkin {
     return Facebook::Graph::Publish::Checkin->new( %params );
 }
 
-sub add_like {
-    my ($self, $object_name, %params) = @_;
-    $params{object_name} = $object_name;
-    if ($self->has_access_token) {
-        $params{access_token} = $self->access_token;
-    }
-    if ($self->has_secret) {
-        $params{secret} = $self->secret;
-    }
-    return Facebook::Graph::Publish::Like->new( %params );
-}
-
 sub add_comment {
     my ($self, $object_name, %params) = @_;
     $params{object_name} = $object_name;
@@ -218,17 +205,6 @@ sub add_comment {
     return Facebook::Graph::Publish::Comment->new( %params );
 }
 
-sub add_link {
-    my ($self, %params) = @_;
-    if ($self->has_access_token) {
-        $params{access_token} = $self->access_token;
-    }
-    if ($self->has_secret) {
-        $params{secret} = $self->secret;
-    }
-    return Facebook::Graph::Publish::Link->new( %params );
-}
-
 sub add_page_tab {
     my ($self, $object_name, $app_id, %params) = @_;
 
@@ -294,10 +270,6 @@ sub rsvp_declined {
 
 Facebook::Graph - A fast and easy way to integrate your apps with Facebook.
 
-=head1 VERSION
-
-version 1.1101
-
 =head1 SYNOPSIS
 
  my $fb = Facebook::Graph->new;
@@ -498,15 +470,6 @@ Creates a L<Facebook::Graph::Publish::Checkin> object, which can be used to publ
 Optionally provide an user id to check in. Requires that you have administrative access to that user.
 
 
-=head2 add_like ( id )
-
-Creates a L<Facebook::Graph::Publish::Like> object to tell everyone about a post you like.
-
-=head3 id
-
-The id of a post you like.
-
-
 =head2 add_comment ( id )
 
 Creates a L<Facebook::Graph::Publish::Comment> object that you can use to comment on a note.
@@ -516,11 +479,6 @@ Creates a L<Facebook::Graph::Publish::Comment> object that you can use to commen
 The id of the post you want to comment on.
 
 
-=head2 add_link ( )
-
-Creates a L<Facebook::Graph::Publish::Link> object, which can be used to publish links.
-
-
 =head2 add_page_tab ( page_id, app_id )
 
 Creates a L<Facebook::Graph::Publish::PageTab> object, which can be used to publish an app as a page tab.
@@ -651,3 +609,5 @@ JT Smith <jt_at_plainblack_dot_com>
 Facebook::Graph is Copyright 2010 - 2012 Plain Black Corporation (L<http://www.plainblack.com>) and is licensed under the same terms as Perl itself.
 
 =cut
+
+
